==> fjp-0.1.0.tgz: package/es/monads/Either/index.js <==
var _createClass = /*#__PURE__*/ function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import Maybe from './../Maybe';

var Either = /*#__PURE__*/function () {
  function Either() {
    _classCallCheck(this, Either);
  }

  _createClass(Either, [{
    key: 'join',
    value: function join() {
      if (this.value instanceof Either) {
        return this.value.join();
      }

      return this;
    }
  }, {
    key: 'map',
    value: function map(fn) {
      return Either.of(fn(this._val));
    }
  }, {
    key: 'flatMap',
    value: function flatMap(fn) {
      return this.map(fn).join();
    }
  }, {
    key: 'filter',
    value: function filter() {
      return this;
    }
  }, {
    key: 'chain',
    value: function chain(fn) {
      return this.isRight ? fn(this._val) : this;
    }
  }, {
    key: 'cata',
    value: function cata(leftFn, rightFn) {
      return this.isRight ? rightFn(this._val) : leftFn(this._val);
    }
  }, {
    key: 'orElseFn',
    value: function orElseFn() {
      return this;
    }
  }, {
    key: 'toMaybe',
    value: function toMaybe() {
      return this.cata(Maybe.None, Maybe.Just);
    }
  }, {
    key: 'isRight',
    get: function get() {
      return false;
    }
  }, {
    key: 'isLeft',
    get: function get() {
      return false;
    }
  }, {
    key: 'value',
    get: function get() {
      return this._val;
    }
  }], [{
    key: 'of',
    value: function of(x) {
      // eslint-disable-next-line no-use-before-define
      return x !== undefined && x !== null && !(x instanceof Error) ? new _Right(x) : // eslint-disable-line no-use-before-define
      new _Left(x); // eslint-disable-line no-use-before-define
    }
  }, {
    key: 'fromNullable',
    value: function fromNullable(x) {
      return Either.of(x);
    }
  }, {
    key: 'Right',
    value: function Right(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Right(x);
    }
  }, {
    key: 'Left',
    value: function Left(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Left(x);
    }
  }, {
    key: 'try',
    value: function _try(fn) {
      try {
        var result = fn();

        return Either.of(result);
      } catch (e) {
        // eslint-disable-next-line new-cap
        return Either.Left(e);
      }
    }
  }]);

  return Either;
}();

var _Right = /*#__PURE__*/function (_Either) {
  _inherits(_Right, _Either);

  function _Right(val) {
    _classCallCheck(this, _Right);

    var _this = _possibleConstructorReturn(this, (_Right.__proto__ || Object.getPrototypeOf(_Right)).call(this));

    _this._val = val;
    return _this;
  }

  _createClass(_Right, [{
    key: 'filter',
    value: function filter(fn) {
      Either.of(fn(this._val) ? this._val : null);
    }
  }, {
    key: 'orElse',
    value: function orElse() {
      return this._val;
    }
  }, {
    key: 'asyncChain',
    value: function () {
      var _ref = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(fn) {
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return fn(this._val);

              case 2:
                return _context.abrupt('return', _context.sent);

              case 3:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function asyncChain(_x) {
        return _ref.apply(this, arguments);
      }

      return asyncChain;
    }()
  }, {
    key: 'toString',
    value: function toString() {
      return 'Either.Right(' + this.value + ')';
    }
  }, {
    key: 'isRight',
    get: function get() {
      return true;
    }
  }]);

  return _Right;
}(Either);

var _Left = /*#__PURE__*/function (_Either2) {
  _inherits(_Left, _Either2);

  function _Left(val) {
    _classCallCheck(this, _Left);

    var _this2 = _possibleConstructorReturn(this, (_Left.__proto__ || Object.getPrototypeOf(_Left)).call(this));

    _this2._val = val;
    return _this2;
  }

  _createClass(_Left, [{
    key: 'orElse',
    value: function orElse(other) {
      return other;
    }
  }, {
    key: 'orElseFn',
    value: function orElseFn(fn) {
      return fn(this._val);
    }
  }, {
    key: 'toString',
    value: function toString() {
      return 'Either.Left(' + this._val + ')';
    }
  }, {
    key: 'isLeft',
    get: function get() {
      return true;
    }
  }]);

  return _Left;
}(Either);

export default Either;

==> fjp-0.2.3.tgz: package/es/monads/Either/index.js <==
import _regeneratorRuntime from 'babel-runtime/regenerator';
import _asyncToGenerator from 'babel-runtime/helpers/asyncToGenerator';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import Maybe from './../Maybe';

var Either = /*#__PURE__*/function () {
  function Either() {
    _classCallCheck(this, Either);
  }

  _createClass(Either, [{
    key: 'join',
    value: function join() {
      if (this.value instanceof Either) {
        return this.value.join();
      }

      return this;
    }
  }, {
    key: 'map',
    value: function map(fn) {
      return Either.of(fn(this._val));
    }
  }, {
    key: 'flatMap',
    value: function flatMap(fn) {
      return this.map(fn).join();
    }
  }, {
    key: 'filter',
    value: function filter() {
      return this;
    }
  }, {
    key: 'chain',
    value: function chain(fn) {
      return this.isRight ? fn(this._val) : this;
    }
  }, {
    key: 'cata',
    value: function cata(leftFn, rightFn) {
      return this.isRight ? rightFn(this._val) : leftFn(this._val);
    }
  }, {
    key: 'orElseFn',
    value: function orElseFn() {
      return this;
    }
  }, {
    key: 'toMaybe',
    value: function toMaybe() {
      return this.cata(Maybe.None, Maybe.Just);
    }
  }, {
    key: 'isRight',
    get: function get() {
      return false;
    }
  }, {
    key: 'isLeft',
    get: function get() {
      return false;
    }
  }, {
    key: 'value',
    get: function get() {
      return this._val;
    }
  }], [{
    key: 'of',
    value: function of(x) {
      // eslint-disable-next-line no-use-before-define
      return x !== undefined && x !== null && !(x instanceof Error) ? new _Right(x) : // eslint-disable-line no-use-before-define
      new _Left(x); // eslint-disable-line no-use-before-define
    }
  }, {
    key: 'fromNullable',
    value: function fromNullable(x) {
      return Either.of(x);
    }
  }, {
    key: 'Right',
    value: function Right(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Right(x);
    }
  }, {
    key: 'Left',
    value: function Left(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Left(x);
    }
  }, {
    key: 'try',
    value: function _try(fn) {
      try {
        var result = fn();

        return Either.of(result);
      } catch (e) {
        // eslint-disable-next-line new-cap
        return Either.Left(e);
      }
    }
  }]);

  return Either;
}();

var _Right = /*#__PURE__*/function (_Either) {
  _inherits(_Right, _Either);

  function _Right(val) {
    _classCallCheck(this, _Right);

    var _this = _possibleConstructorReturn(this, (_Right.__proto__ || _Object$getPrototypeOf(_Right)).call(this));

    _this._val = val;
    return _this;
  }

  _createClass(_Right, [{
    key: 'filter',
    value: function filter(fn) {
      Either.of(fn(this._val) ? this._val : null);
    }
  }, {
    key: 'orElse',
    value: function orElse() {
      return this._val;
    }
  }, {
    key: 'asyncChain',
    value: function () {
      var _ref = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(fn) {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return fn(this._val);

              case 2:
                return _context.abrupt('return', _context.sent);

              case 3:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function asyncChain(_x) {
        return _ref.apply(this, arguments);
      }

      return asyncChain;
    }()
  }, {
    key: 'toString',
    value: function toString() {
      return 'Either.Right(' + this.value + ')';
    }
  }, {
    key: 'isRight',
    get: function get() {
      return true;
    }
  }]);

  return _Right;
}(Either);

var _Left = /*#__PURE__*/function (_Either2) {
  _inherits(_Left, _Either2);

  function _Left(val) {
    _classCallCheck(this, _Left);

    var _this2 = _possibleConstructorReturn(this, (_Left.__proto__ || _Object$getPrototypeOf(_Left)).call(this));

    _this2._val = val;
    return _this2;
  }

  _createClass(_Left, [{
    key: 'orElse',
    value: function orElse(other) {
      return other;
    }
  }, {
    key: 'orElseFn',
    value: function orElseFn(fn) {
      return fn(this._val);
    }
  }, {
    key: 'toString',
    value: function toString() {
      return 'Either.Left(' + this._val + ')';
    }
  }, {
    key: 'isLeft',
    get: function get() {
      return true;
    }
  }]);

  return _Left;
}(Either);

export default Either;
